#[non_exhaustive]#[repr(u32)]pub enum Policy {
BackgroundFrames = 1,
Images = 2,
OptimizeHmd = 4,
}Expand description
A device or leapd policy.
These can be enabled or disabled via ControllerRef::set_policy and
ControllerRef::clear_policy.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
BackgroundFrames = 1
Receive Frames even when the application does not have focus
(ControllerRef::has_focus).
Images = 2
Receive raw camera Images.
OptimizeHmd = 4
Optimize tracking for head-mounted device (when turned off, tracking is optimized for the device sitting flat on a surface).